@@ -4,7 +4,7 @@
  *
  *	  Profiling plugin for PL/pgSQL instrumentation
  *
- * Copyright (c) 2022-2023, pgEdge
+ * Copyright (c) 2022-2024, pgEdge
  * Copyright (c) 2014-2022, OSCG-Partners
  * Copyright (c) 2008-2014, PostgreSQL Global Development Group
  * Copyright 2006,2007 - EnterpriseDB, Inc.
@@ -1321,9 +1321,6 @@ pl_profiler_linestats_local(PG_FUNCTION_ARGS)
 		}
 	}
 
-	/* clean up and return the tuplestore */
-	tuplestore_donestoring(tupstore);
-
 	PG_RETURN_VOID();
 }
 
@@ -1418,9 +1415,6 @@ pl_profiler_linestats_shared(PG_FUNCTION_ARGS)
 	/* Release the shared lock on the shared memory data. */
 	LWLockRelease(plpss->lock);
 
-	/* clean up and return the tuplestore */
-	tuplestore_donestoring(tupstore);
-
 	PG_RETURN_VOID();
 }
 
@@ -1500,9 +1494,6 @@ pl_profiler_callgraph_local(PG_FUNCTION_ARGS)
 		}
 	}
 
-	/* clean up and return the tuplestore */
-	tuplestore_donestoring(tupstore);
-
 	PG_RETURN_VOID();
 }
 
@@ -1601,9 +1592,6 @@ pl_profiler_callgraph_shared(PG_FUNCTION_ARGS)
 	/* Release the shared lock on the shared memory data. */
 	LWLockRelease(plpss->lock);
 
-	/* clean up and return the tuplestore */
-	tuplestore_donestoring(tupstore);
-
 	PG_RETURN_VOID();
 }
 
@@ -1836,9 +1824,6 @@ pl_profiler_funcs_source(PG_FUNCTION_ARGS)
 		pfree(procSrc);
 	}
 
-	/* clean up and return the tuplestore */
-	tuplestore_donestoring(tupstore);
-
 	PG_RETURN_VOID();
 }
 
